@@ -1,6 +1,7 @@
 import argparse
 from typing import BinaryIO
-__version__ = '0.0.1'
+__version__ = '0.0.4'
+
 class ArrayIO(BinaryIO):
     '''In-place BinaryIO Wrapper for bytearray and alikes'''
     n = 0
@@ -19,14 +20,4 @@ class ArrayIO(BinaryIO):
         b = b if self.tell() + len(b) <= len(self.array) else b[:len(self.array) - self.tell()]
         self.array[self.tell():len(b)] = b
         return len(b)    
-
-'''CLI Utilites'''
-def create_default_parser(description='<default tool name>'):
-    '''Creates an `argparser` with `game` as its first positional argument'''
-    parser = argparse.ArgumentParser(
-        description=description, formatter_class=argparse.RawTextHelpFormatter)
-    parser.add_argument('game', metavar='GAME',
-                        help='Game name (i.e. shortnames,for Jojo HFTF it\'s jojoban)')
-    return parser
-
-from .games import *
\ No newline at end of file
+from .games import *
